addSigColor: Add row color or cellcolor for rows or cells of p-value less...

View source: R/ztable2.R

addSigColorR Documentation

Add row color or cellcolor for rows or cells of p-value less than sigp in a ztable

Description

Add row color or cellcolor for rows or cells of p-value less than sigp in a ztable

Usage

addSigColor(z, level = 0.05, bg = "lightcyan", color = "black")

Arguments

z

An object of ztable

level

A p-value

bg

A character indicating background color

color

A character indicating color


ztable documentation built on June 19, 2026, 5:07 p.m.