align2lines: count the vertical column lines from align of Latex format

View source: R/print.ztable.html.R

align2linesR Documentation

count the vertical column lines from align of Latex format

Description

count the vertical column lines from align of Latex format

Usage

align2lines(align)

Arguments

align

A string of align Latex format

Value

a numeric vector consists of vertical lines of each column


ztable documentation built on June 19, 2026, 5:07 p.m.