color2hex: Convert a named color into a hexadecimal color with rgb value

View source: R/ztable2flextable.R

color2hexR Documentation

Convert a named color into a hexadecimal color with rgb value

Description

Convert a named color into a hexadecimal color with rgb value

Usage

color2hex(color)

Arguments

color

A named color

Value

a hexadecimal color

Examples

color2hex("green")
color2hex("red")

ztable documentation built on June 19, 2026, 5:07 p.m.