dot-onAttach: Hooks for Namespace Events

.onAttachR Documentation

Hooks for Namespace Events

Description

Functions to be called when loaded, attached, detached or unloaded

Usage

.onAttach(libname, pkgname)

Arguments

libname

a character string giving the library directory where

pkgname

a character string giving the name of the package.


ztable documentation built on June 19, 2026, 5:07 p.m.