getNewAlign: Make a character string indicating the alignment of...

View source: R/print.ztable.html.R

getNewAlignR Documentation

Make a character string indicating the alignment of components of table.

Description

Make a character string indicating the alignment of components of table.

Usage

getNewAlign(z)

Arguments

z

An object of ztable


ztable documentation built on June 19, 2026, 5:07 p.m.