trim.ztable: Make align and edit p value column for an object of class...

View source: R/ztable.mytable.R

trim.ztableR Documentation

Make align and edit p value column for an object of class ztable.mytable

Description

Make align and edit p value column for an object of class ztable.mytable

Usage

trim.ztable(z)

Arguments

z

An object of class ztable.mytable


ztable documentation built on June 19, 2026, 5:07 p.m.