zcolors: Definition of Latex Color

zcolorsR Documentation

Definition of Latex Color

Description

A dataset containing the name of color and Hex-triplets and latex definition

Usage

zcolors

Format

A data frame with 749 rows and 3 variables:

name

Color name

rgb

Hex triplet of color

definition

Latex command of color definition

Details

To use this color definition, a latex package "color" should be included in your preamble.


ztable documentation built on June 19, 2026, 5:07 p.m.